@@ -11,7 +11,6 @@
 use strict;
 use warnings;
 package main;
-our $VERSION = '0.006';
 use Text::Roman;
 use WebService::Solr;
 use Term::ProgressBar::Simple;
@@ -41,31 +40,3 @@ foreach my $i ( 1 .. $count ) {
 }
 $solr->commit;
 $solr->optimize;
-
-__END__
-=pod
-
-=head1 NAME
-
-main
-
-=head1 VERSION
-
-version 0.006
-
-=head1 AUTHORS
-
-  David Golden <dagolden@cpan.org>
-  Ricardo Signes <rjbs@cpan.org>
-  Leon Brocard <acme@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2010 by David Golden.
-
-This is free software, licensed under:
-
-  The Apache License, Version 2.0, January 2004
-
-=cut
-
